// room.h - John K. Estell - 31 January 2002
// header file for implementation of a room
// Implementation supports travel in six directions
// (north, south, east, west, up, down), items in room,
// and both brief and full text descriptions of the room.

#ifndef ROOM_H
#define ROOM_H

#include <string>
#include <vector>
#include "item.h"
#include "command.h"
using namespace std;


const int BLOCKED = -1;   // indicates travel is blocked in that direction

class Room {
public:
	Room( int n, int s, int e, int w, int u, int d, int pts,
		  string briefDescr, string longDescr );
	bool canTravelOnThis( direction heading ) const;  
	bool hasVisitedRoom( bool isInRoom );
	int getRoomPoints() const;
	int getRoomTravelingOnThis( direction heading ) const;
	string getBriefRoomDescription() const;
	string getRoomDescription() const;
	vector<Item *> getRoomContents();
	bool isItemInRoom( string namedItem );
	Item *removeFromRoom( string namedItem );
	void addToRoom( Item *thisItem );

private:
	int roomTravelDirection[ 6 ];  // entries correspond to order in direction enum type
	int roomPoints;
	bool hasVisitedFlag;
	string briefRoomDescription;
	string roomDescription;
	vector<Item *> roomContents;
};

// Auxiliary functions: getRoomDataRecords reads in room information.
// Rooms are stored as multiple-line records in the specified data file:
// Line 1: data in comment form containing room number. 
//         Rooms are sequentially enumerated beginning at zero.
// Line 2: six integers indicating the ability to travel (in order) 
//         north, south, east, west, up, or down from the current room. 
//         The value -1 is used to indicate that one cannot travel in that 
//         direction; any other value indicates the room number of the room 
//         that would be visited if one travels in that direction.
// Line 3: points received for visiting this room.
// Line 4: name of image file used by your graphics package to illustrate 
//         where you are. Make sure there is no whitespace in the filename.
//         Just read and ignore (or remove entirely) if not using graphics.
// Line 5: one line (i.e. short) description of where you are. 
//         Short descriptions are often used when revisiting a room.
// Line 6: start of (long) descriptive room text. Text will be formatted on 
//         the display exactly as it appears in the data file. Multiple lines 
//         are permitted; you may assume that a single line of input contains 
//         no more than 100 characters. The word END at the beginning of a line 
//         is used to indicate the end of the descriptive text.
vector<Room *> getRoomDataRecords( string roomDataFile );

#endif